@@ -1,40 +1,48 @@
-from abc import abstractmethod
+from abc import abstractmethod, ABC
 from typing import Callable, Dict
+
 from munch import Munch
-
-from entropylab.pipeline.api.in_process_param_store import InProcessParamStore
-from qualang_tools.config import ConfigBuilder
-from qualang_tools.config.parameters import ConfigVars
 from qm.QuantumMachinesManager import QuantumMachinesManager
+from qualang_tools.config import ConfigBuilder
+from qualang_tools.config import ConfigurationError
+from qualang_tools.config.parameters import ConfigVars
+
+from entropylab import ParamStore
 
 
-class QuAMCore(object):
-    def __init__(self, path: str):
-        """Core QUAM object
+class QuAMManager(ABC):
+    def __init__(self, path: str, host=None, port=None, **kwargs):
+        """
+        QuAMManager
+        :param host: Host where to find the QM orchestrator. If ``None``,
+            local settings are used.
+        :type host: str
+        :param port: Port where to find the QM orchestrator. If None, local settings
+         are used):
+        :type port: int
         :param path: Path of the entropy DB
         :type path: str
         """
         self.path = path
-        self.param_store = InProcessParamStore(path)
-
-
-class QuAMManager(QuAMCore):
-    def __init__(self, path: str, **qmm_kwargs):
-        """Admin
-        :param path: Path of the entropy DB
-        :type path: str
-        """
-        super().__init__(path=path)
-        self._qmm_kwargs = qmm_kwargs
+        self.param_store = ParamStore(path)
         self._config_builder = ConfigBuilder()
         self._config_vars = ConfigVars()
+        self.config = {}
+        self.host = host
+        self.port = port
+        self.qmm = QuantumMachinesManager(host=host, port=port, **kwargs)
 
     def generate_config(self):
         """Returns the QUA configuration"""
         self._config_builder = ConfigBuilder()
         self.prepare_config(self._config_builder)
         self._set_config_vars()
-        return self._config_builder.build()
+        self.config = self._config_builder.build()
+        return self.config
+
+    @property
+    def config_builder(self):
+        return self._config_builder
 
     @abstractmethod
     def prepare_config(self, cb: ConfigBuilder) -> None:
@@ -56,44 +64,28 @@ class QuAMManager(QuAMCore):
         _dict = {}
         for k in self.param_store.keys():
             if not callable(self._config_vars.parameter(k)._value):
+                if self.param_store[k] is None:
+                    raise ConfigurationError("Set parameter {}".format(k))
                 _dict[k] = self.param_store[k]
         self._config_vars.set(**_dict)
 
-    def open_quam(self):
-        """Returns an instance of QuAM
-        :return: a quam
-        :rtype: QuAM
-        """
-        self._set_config_vars()
-        return QuAM(path=self.path, config=self.generate_config(), **self._qmm_kwargs)
-
-
-class QuAM(QuAMCore):
-    def __init__(self, path: str, config: dict = None, **qmm_kwargs):
-        """User class to facilitate writing and execution of QUA programs
-        :param path: path to the entropy DB
-        :type path: str
-        :param config: a QUA configuration, defaults to an empty dictionary
-        :type config: Dict, optional
-        """
-        super().__init__(path=path)
-        self.config = config if config is not None else {}
-        self.qmm = QuantumMachinesManager(**qmm_kwargs)
-
     @property
     def elements(self):
         """Returns a Munch instance of element keys available in the QUA configuration"""
-        return dict_keys_to_munch(self.config["elements"])
+        return get_key("elements", self.config)
 
     @property
     def pulses(self):
         """Returns a Munch instance of pulses available in the QUA configuration"""
-        return dict_keys_to_munch(self.config["pulses"])
+        return get_key("pulses", self.config)
 
     @property
     def integration_weights(self):
         """Returns a Munch instance of integration weights available in the QUA configuration"""
-        return dict_keys_to_munch(self.config["integration_weights"])
+        return get_key("integration_weights", self.config)
+
+    def open_qm(self):
+        return self.qmm.open_qm(self.generate_config())
 
 
 def dict_keys_to_munch(d: Dict):
@@ -101,3 +93,15 @@ def dict_keys_to_munch(d: Dict):
     for k in d.keys():
         elms[k] = k
     return elms
+
+
+def get_key(k: str, d: dict):
+    if k in d:
+        return dict_keys_to_munch(d[k])
+    else:
+        raise KeyError(
+            "{} doesn't exist in the QUA configuration, probably the \
+                config wasn't generated".format(
+                k
+            )
+        )
